@@ -122,18 +122,24 @@ Step.prototype.capabilityFlagDefault = function ( flag ) {
     if ( this.conf[c] &&
          this.conf[c].path != undefined && // looks like a jsonPath
          this.conf[c].key != undefined ) {
-      /*dump("Capdef: '" + flag + "' " +
+      if(0) logger.debug ("Capdef: " +   // ###
+        "f='" + flag + "' " +
         "p='" + this.conf[c].path +"' " +
-        "k='" + this.conf[c].key +"' " +
-        "\n"); */
+        "k='" + this.conf[c].key +"' " );
       if ( c != 'out'  &&
            jsonPathHelper.capabilityFlagDefault(
              this.conf[c], flag, "$.input", "index") )
         return true;
       if ( c != 'in' &&
            jsonPathHelper.capabilityFlagDefault(
-            this.conf[c], flag, "$.output", "result") )
+            this.conf[c], flag, "$.output.results", "result") )
         return true;
+      if ( c != 'in' &&
+           jsonPathHelper.capabilityFlagDefault(
+            this.conf[c], flag, "$.output.facets", "facet") )
+        return true;
+      // TODO - It is not nice to mention output.results and facets here,
+      // they should come from the template directly. See also CP-3739
     }
     // Many steps store conditions. These test input but don't generate results
     if (c === 'conditions' && jsonPathHelper.conditionsCapable(
