@@ -173,7 +173,8 @@ Httpclient.prototype.run = function (task) {
     //task.debug("event: " + event );
     try {
       if (e) {
-        core.getBrowser().removeEventListener(event, eventhandler, false);
+        task.connector.getPageWindow().
+          removeEventListener(event, eventhandler, false);
       }
       var doc = task.connector.getRealPageDoc();
       doc.body.innerHTML = "HTTP client sending a " +
@@ -240,9 +241,10 @@ Httpclient.prototype.run = function (task) {
       eventhandler(false);
     } else {
       task.debug("About to blank the page (cur=" + curloc + ")");
-      core.getBrowser().addEventListener(event, eventhandler, false);
+      task.connector.getPageWindow().
+          addEventListener(event, eventhandler, false);
       task.interrupt(30000,interruptcallback);  // 30 secs
-      core.getBrowser().loadURI("about:blank");
+      this.getPageDoc().location = "about:blank";
     }
 
 };
