@@ -694,20 +694,32 @@ ProxyUrl.prototype.sessioncontent = function (task, session, init) {
 
 ProxyUrl.prototype.writesessionfile= function (task, session, content) {
   var sesdir = ConfigFile.getconfigvalue(task, "sessiondir");
-  if ( sesdir ) {
-    var sesfilename = sesdir + "/cf." + session ;
-    var sesfile = Components.classes["@mozilla.org/file/local;1"].
-        createInstance(Components.interfaces.nsILocalFile);
-        sesfile.initWithPath(sesfilename);
-    var fos = io.fos(sesfile, "" );  // file output stream
-    io.write(fos,content);  // writes the string and closes fos!
-    // If these throw exceptions, we are configured badly, and en
-    // exception is all right
-    task.info("ProxyURL session file stored at "+sesfile.path);
-  } else {
+  if ( !sesdir ) {
     // Do not throw an error, breaks the builder if no access to /etc
+    // or no cfg file
     task.warn("Can not store session file " + session + ". " +
-        "No 'sessiondir' found in config file");
+        "No 'sessiondir' found in config file. " +
+        "Install cf-proxy?" );
+    return; 
+  }
+  try {
+  var sesfilename = sesdir + "/cf." + session ;
+  var sesfile = Components.classes["@mozilla.org/file/local;1"].
+      createInstance(Components.interfaces.nsILocalFile);
+      sesfile.initWithPath(sesfilename);
+  var fos = io.fos(sesfile, "" );  // file output stream
+  io.write(fos,content);  // writes the string and closes fos!
+  // If these throw exceptions, we are configured badly, and en
+  // exception is all right
+  task.info("ProxyURL session file stored at "+sesfile.path);
+  } catch (e) {
+    logger.error("Storing session file " + sesfilename + " failed! " +
+      e.name + " " + e.message );
+    if ( e.fileName && e.lineNumber )
+      logger.error("  in " + e.fileName + ":" +  e.lineNumber );
+    e.message = "Storing session file " + sesfilename + " failed: " +
+        e.message;
+    throw(e);
   }
 }; // writesessionfile
 
@@ -874,18 +886,18 @@ ProxyUrl.prototype.upgrade = function (confVer, curVer, conf) {
     // the various omit_ flags default to false, no need to set them explicitly
   }
   if ( confVer < 1.3 ) {
-    cookiedomainexpansions = [];
-    omitcookies = [];
-    skiplines = [];
-    replacements = [];
-    extras = [];
+    conf.cookiedomainexpansions = [];
+    conf.omitcookies = [];
+    conf.skiplines = [];
+    conf.replacements = [];
+    conf.extras = [];
     logger.debug("Upgraded extra parameters from confVer to empty defaults");
   }
   if ( confVer < 1.4 ) {
-    basicauthwith = [];
-    omit_baseurl = true; // default to the old behavior, even though it
-                         // doesn't make that much sense.
-    omit_referer = false;
+    conf.basicauthwith = [];
+    conf.omit_baseurl = true; // default to the old behavior, even though it
+                             // doesn't make that much sense.
+    conf.omit_referer = false;
   }
   return true;
 };
