@@ -64,11 +64,10 @@ var htmlHelper = {
         xml.cf_displaynode = div;
         docnode.appendChild(div);
       }
-      if ( xml.firstChild ) { // render children, and a closing tag
+      if ( xml.firstChild && ! div.cf_rendered ) { // render children, and a closing tag
         htmlHelper._renderXml_recursive( xml.firstChild, doc, div, indent+1);
         var div2 = htmlHelper._renderXmlNode( xml, doc, docnode, ind, false);
         if (div2) {
-          //docnode.appendChild(div2);
           div.appendChild(div2);
         }
       }
@@ -76,6 +75,7 @@ var htmlHelper = {
     }
   },
 
+
   // Helper to render one XML node, either its start or end tag
   _renderXmlNode: function ( xml, doc, docnode, ind, starttag ) {
     var div = doc.createElement("div");
@@ -116,6 +116,24 @@ var htmlHelper = {
       } else
         return false;
     }
+    // One-liner: only one short #text node, 
+    if ( xml.firstChild &&
+         xml.firstChild.nodeName == "#text" &&  
+         ! xml.firstChild.nextSibling &&
+         ! xml.hasAttributes() ) {
+      var txt = xml.firstChild.nodeValue;
+      if ( txt.match( /\S/) &&  // non-whitespace
+           txt.length < 50 ) { // and not too long
+        div.style.color = "black";
+        div.innerHTML = ind +
+          "<span style='color:blue'>&lt;" + xml.nodeName + "&gt;</span>" +
+          "<span stype='color:red'>" + txt + "</span>" +
+          "<span style='color:blue'>&lt;/" + xml.nodeName + "&gt;</span>" +
+          "</br>\n";
+        div.cf_rendered = "yes";
+        return div;
+      }
+    }
     // default to regular node
     var attrstr = "";
     if ( starttag ) {
