@@ -492,7 +492,13 @@ bool CF_Embed::wait_init_handshake(std::string &error_msg)
 
     const char *output = 0;
     bool sys_err = false;
-    bool res = wait_result_parent(&output, 20000, &sys_err);
+    int wait_init = 20;
+    {
+        char *str = getenv("CF_WAIT_INIT");
+        if (str)
+            wait_init = atoi(str);
+    }
+    bool res = wait_result_parent(&output, wait_init * 1000, &sys_err);
     yaz_timing_stop(myt);
 
     logger->printf("timing", YLOG_LOG,
@@ -806,7 +812,14 @@ CF_Embed::~CF_Embed()
         wrbuf_destroy(w);
 
         bool sys_err = false;
-        wait_result_parent(&output, 20000, &sys_err);
+
+        int wait_init = 20;
+        {
+            char *str = getenv("CF_WAIT_INIT");
+            if (str)
+                wait_init = atoi(str);
+        }
+        wait_result_parent(&output, wait_init * 1000, &sys_err);
 
         logger->printf("engine", YLOG_LOG, "waiting for threads to join");
         pthread_join(child_thread, 0); // and wait for it to stop
@@ -941,8 +954,13 @@ void CF_Embed::get_result_parent(const char *default_msg, const char **output)
 {
     bool sys_err = false;
     assert(output);
-    // wait up to two minutes for ANY operation
-    if (!wait_result_parent(output, 120000, &sys_err))
+    int wait_task = 120;
+    {
+        char *str = getenv("CF_WAIT_TASK");
+        if (str)
+            wait_task = atoi(str);
+    }
+    if (!wait_result_parent(output, wait_task * 1000, &sys_err))
     {
         if (*output && **output)
         {
