@@ -82,9 +82,14 @@ public:
 	page_offset++;
 	if (page_offset == 1)
 	{
-            nsIWebBrowser* browser = static_cast<nsIWebBrowser*>(moz_web_view_get_browser(mView));
-            m_connector.setBrowser(browser);
-            get_CF_Embed()->browser_ready(&m_connector);
+            if (m_connector.setBrowserWindow(win))
+            {
+                nsIWebBrowser* browser = static_cast<nsIWebBrowser*>(moz_web_view_get_browser(mView));
+                m_connector.setBrowser(browser);
+                get_CF_Embed()->browser_ready(&m_connector);
+            }
+            else
+                get_CF_Embed()->browser_failure("connectorWrap failed");
 
 	    moz_web_get_messages(mView);
 	}
