@@ -36,24 +36,31 @@ int main(int argc, char **argv)
     YAZ_PQF_Parser parser = yaz_pqf_create();
     ODR odr = odr_createmem(ODR_ENCODE);
 
+    if (!input_pqf)
+    {
+        fprintf(stderr, "missing query\n");
+        exit(1);
+    }
     Z_RPNQuery *q = yaz_pqf_parse(parser, odr, input_pqf);
     yaz_pqf_destroy(parser);
 
-    if (q)
+    if (!q)
     {
-        struct sort_elem *sort_list = 0, *sl;
-        NMEM nmem = nmem_create();
-        WRBUF pqf_result = wrbuf_alloc();
-        type7_sort(q, nmem, &sort_list);
-
-        yaz_rpnquery_to_wrbuf(pqf_result, q);
-        printf("%s\n", wrbuf_cstr(pqf_result));
-        for (sl = sort_list; sl; sl = sl->next)
-            printf("prio=%d field=%s flags=%s\n",
-                   sl->prio, sl->field, sl->flags);
-        nmem_destroy(nmem);
-        wrbuf_destroy(pqf_result);
+        fprintf(stderr, "PQF parsing failed\n");
+        exit(1);
     }
+    struct sort_elem *sort_list = 0, *sl;
+    NMEM nmem = nmem_create();
+    WRBUF pqf_result = wrbuf_alloc();
+    type7_sort(q, nmem, &sort_list);
+
+    yaz_rpnquery_to_wrbuf(pqf_result, q);
+    printf("%s\n", wrbuf_cstr(pqf_result));
+    for (sl = sort_list; sl; sl = sl->next)
+        printf("prio=%d field=%s flags=%s\n",
+               sl->prio, sl->field, sl->flags);
+    nmem_destroy(nmem);
+    wrbuf_destroy(pqf_result);
     odr_destroy(odr);
     exit(0);
 }
